@@ -7,10 +7,18 @@ has 'table_name' => "tools_objects";
 
 
 
-sub load_tools_objects_fkey($self, $tools_projects_pkey) {
+
+sub load_tools_object_pkey($self, $tools_objects_pkey) {
+
+    return $self->load_pk(
+        $self->table_name, $self->fields(), $self->primary_key_name(), $tools_objects_pkey
+    );
+}
+
+sub load_tools_objects_fkey($self, $tools_version_pkey) {
 
     return $self->load_fkey(
-        $self->table_name, $self->fields(), "tools_version_fkey", $tools_projects_pkey
+        $self->table_name, $self->fields(), "tools_version_fkey", $tools_version_pkey
     );
 }
 
@@ -23,4 +31,6 @@ sub insert_tools_objects($self, $data) {
 sub update_tools_objects($self, $data) {
     return $self->update($self->table_name, $data, { $self->primary_key_name() => $data->{$self->primary_key_name()}});
 }
+
+
 1;
\ No newline at end of file
